@@ -1,7 +1,8 @@
 # coloring.
-from colorama import Fore
 import colorama
-colorama.init()
+from colorama import Fore, init 
+
+init()
 
 # object that contains the simulation data.
 class MonteCarlo:
@@ -68,6 +69,7 @@ class MonteCarlo:
         __documentation__,
         __contact__,
         __donate__,
+        __APPversion__,
     )
 
     # initial launch.
@@ -90,7 +92,7 @@ class MonteCarlo:
         self.ref_value_index = ref_value_index
         print(Fore.GREEN + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
         from vandal.hub.toolkit import random_value
-        print('NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.')
+        print(Fore.RED + 'NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.' + Fore.RESET)
         #print('The model that will be able to handle big standard deviations is currently being worked on, thank you for your patience.\n')
         import pandas as pd
         # this removes pandas warning of highly fragmented DataFrame for newer pandas versions.
@@ -161,7 +163,7 @@ class MonteCarlo:
 
         assert (NRisk < 100), '\nTime sequence and/or number of iterations are too low for the proper risk calculation.'
 
-        print(Fore.GREEN + '\nRisk for this option is' + Fore.RESET, round(NRisk,2), '%.')
+        print(Fore.GREEN + '\nRisk for this option is' + Fore.RESET, round(NRisk,2), Fore.GREEN + '%.' + Fore.RESET)
 
     # plots the Monte Carlo simulation on a graph.
     def graph(self, graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True):
@@ -246,6 +248,7 @@ class MonteCarlo:
 def MCapp():
 
     '''
+    
     runs as:
 
         *IDE: vandal.MCapp()
@@ -255,20 +258,20 @@ def MCapp():
 
     # relevant imports.
     import os
-    from vandal.misc._meta import __version__
-    from vandal.objects import MonteCarlo
+    from vandal.misc._meta import (
+        __version__,
+        __APPversion__,
+    )
+    from vandal.objects.montecarlo import MonteCarlo
     from vandal.hub.toolkit import (
         save_to,
         file_handler,
     )
     os.system('cls')
 
-    # vandal.App version.
-    __APPversion__ = 'v 1.3.0'
-    
     # greeting.
-    print(Fore.GREEN + '\n - vandal Command Line Interface Application © David Kundih -', __APPversion__)
-    print(Fore.GREEN + ' - vandal package version -', 'v',__version__, Fore.RESET, '\n')
+    print(Fore.YELLOW + '\n - vandal Command Line Interface Application © David Kundih -', __APPversion__)
+    print(Fore.YELLOW + ' - vandal package version -', 'v',__version__, Fore.RESET, '\n')
     print(Fore.YELLOW + 'DATA INPUT OPTIONS', Fore.RESET)
     print('0 | Manual input')
     print('1 | File input\n')
@@ -312,7 +315,7 @@ def MCapp():
 
     # options after defining the parameters. 
     while True:
-        action = input('\n>>> ACTIONS: graph, change, values, stats, risk, hist, home, help: ')
+        action = input('\n>>> ACTIONS: graph, change, values, stats, risk, hist, help, home: ')
         if action == 'graph':
             print('')
             title = input('Title: ')
